You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by dh...@apache.org on 2016/07/26 23:35:37 UTC

[1/2] incubator-beam git commit: Reuse context and disable UI.

Repository: incubator-beam
Updated Branches:
  refs/heads/master 68850b4b8 -> e8695a1b6


Reuse context and disable UI.

Rename dataflow to beam.


Project: http://git-wip-us.apache.org/repos/asf/incubator-beam/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-beam/commit/e62bfdb1
Tree: http://git-wip-us.apache.org/repos/asf/incubator-beam/tree/e62bfdb1
Diff: http://git-wip-us.apache.org/repos/asf/incubator-beam/diff/e62bfdb1

Branch: refs/heads/master
Commit: e62bfdb16dddfd19fc881e8a78df956bd0ef0ff1
Parents: 68850b4
Author: Sela <an...@paypal.com>
Authored: Tue Jul 26 23:47:06 2016 +0300
Committer: Sela <an...@paypal.com>
Committed: Tue Jul 26 23:50:01 2016 +0300

----------------------------------------------------------------------
 runners/spark/pom.xml                                        | 7 ++++++-
 .../beam/runners/spark/translation/SparkContextFactory.java  | 8 ++++----
 2 files changed, 10 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-beam/blob/e62bfdb1/runners/spark/pom.xml
----------------------------------------------------------------------
diff --git a/runners/spark/pom.xml b/runners/spark/pom.xml
index 60d9ef3..e34bc5d 100644
--- a/runners/spark/pom.xml
+++ b/runners/spark/pom.xml
@@ -83,7 +83,8 @@
                           "--streaming=false"
                         ]
                       </beamTestPipelineOptions>
-                      <dataflow.spark.test.reuseSparkContext>true</dataflow.spark.test.reuseSparkContext>
+                      <beam.spark.test.reuseSparkContext>true</beam.spark.test.reuseSparkContext>
+                      <spark.ui.enabled>false</spark.ui.enabled>
                     </systemPropertyVariables>
                   </configuration>
                 </execution>
@@ -279,6 +280,10 @@
           <configuration>
             <forkCount>1</forkCount>
             <reuseForks>false</reuseForks>
+            <systemPropertyVariables>
+              <beam.spark.test.reuseSparkContext>true</beam.spark.test.reuseSparkContext>
+              <spark.ui.enabled>false</spark.ui.enabled>
+            </systemPropertyVariables>
           </configuration>
         </plugin>
         <plugin>

http://git-wip-us.apache.org/repos/asf/incubator-beam/blob/e62bfdb1/runners/spark/src/main/java/org/apache/beam/runners/spark/translation/SparkContextFactory.java
----------------------------------------------------------------------
diff --git a/runners/spark/src/main/java/org/apache/beam/runners/spark/translation/SparkContextFactory.java b/runners/spark/src/main/java/org/apache/beam/runners/spark/translation/SparkContextFactory.java
index c58e1dd..e008448 100644
--- a/runners/spark/src/main/java/org/apache/beam/runners/spark/translation/SparkContextFactory.java
+++ b/runners/spark/src/main/java/org/apache/beam/runners/spark/translation/SparkContextFactory.java
@@ -28,12 +28,12 @@ import org.apache.spark.serializer.KryoSerializer;
 public final class SparkContextFactory {
 
   /**
    * If the property {@code dataflow.spark.test.reuseSparkContext} is set to
    * {@code true} then the Spark context will be reused for dataflow pipelines.
    * This property should only be enabled for tests.
    */
-  static final String TEST_REUSE_SPARK_CONTEXT =
-      "dataflow.spark.test.reuseSparkContext";
+  static final String TEST_REUSE_SPARK_CONTEXT = "beam.spark.test.reuseSparkContext";
+
   private static JavaSparkContext sparkContext;
   private static String sparkMaster;
 


[2/2] incubator-beam git commit: Closes #736

Posted by dh...@apache.org.
Closes #736


Project: http://git-wip-us.apache.org/repos/asf/incubator-beam/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-beam/commit/e8695a1b
Tree: http://git-wip-us.apache.org/repos/asf/incubator-beam/tree/e8695a1b
Diff: http://git-wip-us.apache.org/repos/asf/incubator-beam/diff/e8695a1b

Branch: refs/heads/master
Commit: e8695a1b6296e87fbe204f5a530932d7f8d815af
Parents: 68850b4 e62bfdb
Author: Dan Halperin <dh...@google.com>
Authored: Tue Jul 26 16:35:01 2016 -0700
Committer: Dan Halperin <dh...@google.com>
Committed: Tue Jul 26 16:35:01 2016 -0700

----------------------------------------------------------------------
 runners/spark/pom.xml                                        | 7 ++++++-
 .../beam/runners/spark/translation/SparkContextFactory.java  | 8 ++++----
 2 files changed, 10 insertions(+), 5 deletions(-)
----------------------------------------------------------------------
@@ -28,12 +28,12 @@ import org.apache.spark.serializer.KryoSerializer;
 
   /**
-   * If the property {@code dataflow.spark.test.reuseSparkContext} is set to
-   * {@code true} then the Spark context will be reused for dataflow pipelines.
+   * If the property {@code beam.spark.test.reuseSparkContext} is set to
+   * {@code true} then the Spark context will be reused for beam pipelines.
    * This property should only be enabled for tests.
    */